Plugins/VcsPlugins/vcsMercurial/ProjectHelper.py

branch
5_4_x
changeset 3474
ca4b926f1bbb
parent 3436
5f64b3d02ebf
diff -r 741ab2eecaf9 -r ca4b926f1bbb Plugins/VcsPlugins/vcsMercurial/ProjectHelper.py
--- a/Plugins/VcsPlugins/vcsMercurial/ProjectHelper.py	Wed Apr 02 19:08:31 2014 +0200
+++ b/Plugins/VcsPlugins/vcsMercurial/ProjectHelper.py	Thu Apr 03 19:12:51 2014 +0200
@@ -272,7 +272,7 @@
         self.actions.append(self.hgLogBrowserAct)
         
         self.vcsDiffAct = E5Action(
-            self.trUtf8('Show difference'),
+            self.trUtf8('Show differences'),
             UI.PixmapCache.getIcon("vcsDiff.png"),
             self.trUtf8('Show &difference'),
             0, 0, self, 'mercurial_diff')
@@ -280,24 +280,24 @@
             'Show the difference of the local project to the repository'
         ))
         self.vcsDiffAct.setWhatsThis(self.trUtf8(
             """<b>Show difference</b>"""
             """<p>This shows the difference of the local project to the"""
             """ repository.</p>"""
         ))
         self.vcsDiffAct.triggered[()].connect(self._vcsDiff)
         self.actions.append(self.vcsDiffAct)
         
         self.hgExtDiffAct = E5Action(
-            self.trUtf8('Show difference (extended)'),
+            self.trUtf8('Show differences (extended)'),
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show difference (extended)'),
+            self.trUtf8('Show differences (extended)'),
             0, 0, self, 'mercurial_extendeddiff')
         self.hgExtDiffAct.setStatusTip(self.trUtf8(
             'Show the difference of revisions of the project to the repository'
         ))
         self.hgExtDiffAct.setWhatsThis(self.trUtf8(
             """<b>Show difference (extended)</b>"""
             """<p>This shows the difference of selectable revisions of the"""
             """ project.</p>"""
         ))
         self.hgExtDiffAct.triggered[()].connect(self.__hgExtendedDiff)
@@ -280,24 +280,24 @@
         ))
         self.vcsDiffAct.setWhatsThis(self.trUtf8(
-            """<b>Show difference</b>"""
-            """<p>This shows the difference of the local project to the"""
+            """<b>Show differences</b>"""
+            """<p>This shows differences of the local project to the"""
             """ repository.</p>"""
         ))
@@ -280,24 +280,24 @@
         ))
         self.hgExtDiffAct.setWhatsThis(self.trUtf8(
-            """<b>Show difference (extended)</b>"""
-            """<p>This shows the difference of selectable revisions of the"""
+            """<b>Show differences (extended)</b>"""
+            """<p>This shows differences of selectable revisions of the"""
             """ project.</p>"""
         ))

eric ide

mercurial